@@ -1,4 +1,5 @@
 use crate::internal::node_impl::NodeImpl;
+use crate::internal::TreeElementTrait;
 use std::cell::RefCell;
 use std::rc::Weak;
 
@@ -13,3 +14,9 @@ impl<IT, LT> LeafImpl<IT, LT> {
         LeafImpl { parent, value }
     }
 }
+
+impl<IT, LT> TreeElementTrait<IT, LT> for LeafImpl<IT, LT> {
+    fn parent(&mut self) -> &mut Option<Weak<RefCell<NodeImpl<IT, LT>>>> {
+        &mut self.parent
+    }
+}
