@@ -1,4 +1,5 @@
 use super::tree_element_impl::TreeElementImpl;
+use crate::internal::TreeElementTrait;
 use std::cell::RefCell;
 use std::rc::Weak;
 
@@ -18,3 +19,9 @@ impl<IT, LT> NodeImpl<IT, LT> {
         }
     }
 }
+
+impl<IT, LT> TreeElementTrait<IT, LT> for NodeImpl<IT, LT> {
+    fn parent(&mut self) -> &mut Option<Weak<RefCell<NodeImpl<IT, LT>>>> {
+        &mut self.parent
+    }
+}
