@@ -5,7 +5,9 @@ use crate::tree_elements::tree_element::TreeElement;
 pub enum DLTreeError {
     // This error should never happen and is a bug in dltree
     // Please report any occurence of this error
-    DoubleLinkIntegrityViolated,
+    IntegrityViolated,
+    // This error happens if child manipulations like insertions or replacements are applied on the root element
+    ChildOperationOnRootLevel,
 }
 
 pub enum Value<IT, LT> {
@@ -109,12 +111,78 @@ mod tests {
         assert!(sub_sub_tree.parent()?.is_some());
         assert_eq!(sub_tree.as_node().unwrap().children().len(), 1);
         let removed_sub_sub_tree = sub_sub_tree.remove_from_tree()?;
-        removed_sub_sub_tree.root_node().remove_from_tree()?;
+        assert!(removed_sub_sub_tree.root_node().remove_from_tree().is_err());
         assert_eq!(sub_tree.as_node().unwrap().children().len(), 0);
         assert_eq!(tree.root_node().as_node().unwrap().children().len(), 1);
         let removed_sub_tree = sub_tree.remove_from_tree()?;
-        removed_sub_tree.root_node().remove_from_tree()?;
+        assert!(removed_sub_tree.root_node().remove_from_tree().is_err());
         assert_eq!(tree.root_node().as_node().unwrap().children().len(), 0);
         Ok(())
     }
+
+    #[test]
+    fn replace_test() -> Result<(), DLTreeError> {
+        let tree = Tree::<i32, i32>::new(Value::Node(34));
+        let leaf = tree
+            .root_node()
+            .as_node()
+            .unwrap()
+            .push_child(Value::Leaf(45));
+        let mut node = leaf
+            .as_leaf()
+            .unwrap()
+            .set(Value::Node(56))?
+            .as_node()
+            .unwrap();
+        node.push_child(Value::Leaf(67));
+        let sub_leaf = node.set(Value::Leaf(78))?.as_leaf().unwrap();
+        assert_eq!(*sub_leaf.parent()?.unwrap().value(), 34);
+        Ok(())
+    }
+    #[test]
+    fn insert_test() -> Result<(), DLTreeError> {
+        let tree = Tree::<i32, i32>::new(Value::Node(11));
+        tree.root_node()
+            .as_node()
+            .unwrap()
+            .push_child(Value::Leaf(21));
+        let middle_leaf = tree
+            .root_node()
+            .as_node()
+            .unwrap()
+            .push_child(Value::Leaf(22));
+        tree.root_node()
+            .as_node()
+            .unwrap()
+            .push_child(Value::Leaf(23));
+        assert_eq!(
+            tree.root_node()
+                .as_node()
+                .unwrap()
+                .children()
+                .iter()
+                .map(|c| *c.value())
+                .collect::<Vec<i32>>(),
+            vec![21, 22, 23]
+        );
+        middle_leaf
+            .as_leaf()
+            .unwrap()
+            .insert_before(Value::Leaf(44))?;
+        middle_leaf
+            .as_leaf()
+            .unwrap()
+            .insert_after(Value::Node(45))?;
+        assert_eq!(
+            tree.root_node()
+                .as_node()
+                .unwrap()
+                .children()
+                .iter()
+                .map(|c| *c.value())
+                .collect::<Vec<i32>>(),
+            vec![21, 44, 22, 45, 23]
+        );
+        Ok(())
+    }
 }
